Class: KaiserRuby::RockstarSingleLineParser

Inherits:
RockstarParser
  • Object
show all
Defined in:
lib/kaiser_ruby/rockstar_parser.rb

Overview

this is an alternative parser that enables all the RSpec tests to pass it specifically has a single line rule that matches a string instead of lines it also matches the value_or_variable rule, so that the value creation can be tested